@@ -267,9 +267,10 @@ mod tests {
     use super::Parser;
     use crate::types::Asn1Readable;
     use crate::{
-        BigUint, BitString, Choice1, Choice2, Choice3, Enumerated, GeneralizedTime, IA5String,
-        ObjectIdentifier, ParseError, ParseErrorKind, ParseLocation, ParseResult, PrintableString,
-        Sequence, SequenceOf, SetOf, Tlv, UtcTime, Utf8String, VisibleString,
+        BMPString, BigUint, BitString, Choice1, Choice2, Choice3, Enumerated, GeneralizedTime,
+        IA5String, ObjectIdentifier, ParseError, ParseErrorKind, ParseLocation, ParseResult,
+        PrintableString, Sequence, SequenceOf, SetOf, Tlv, UniversalString, UtcTime, Utf8String,
+        VisibleString,
     };
     #[cfg(feature = "const-generics")]
     use crate::{Explicit, Implicit};
@@ -709,6 +710,58 @@ mod tests {
         ])
     }
 
+    #[test]
+    fn test_parse_bmpstring() {
+        assert_parses::<BMPString>(&[
+            (
+                Ok(BMPString::new(b"\x00a\x00b\x00c").unwrap()),
+                b"\x1e\x06\x00a\x00b\x00c",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1e\x01a",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1e\x04\xde|X@",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1e\x02\xdeX",
+            ),
+        ]);
+    }
+
+    #[test]
+    fn test_parse_universalstring() {
+        assert_parses::<UniversalString>(&[
+            (
+                Ok(UniversalString::new(b"\x00\x00\x00a\x00\x00\x00b\x00\x00\x00c").unwrap()),
+                b"\x1c\x0c\x00\x00\x00a\x00\x00\x00b\x00\x00\x00c",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1c\x01a",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1c\x02ab",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1c\x03abc",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1c\x03abc",
+            ),
+            (
+                Err(ParseError::new(ParseErrorKind::InvalidValue)),
+                b"\x1c\x04\x96\x8c\xeaU",
+            ),
+        ]);
+    }
+
     #[test]
     fn test_parse_utctime() {
         assert_parses::<UtcTime>(&[
