@@ -132,10 +132,10 @@ mod tests {
     use super::{_insert_at_position, write, write_single, Writer};
     use crate::types::Asn1Writable;
     use crate::{
-        parse_single, BigUint, BitString, Choice1, Choice2, Choice3, Enumerated, GeneralizedTime,
-        IA5String, ObjectIdentifier, OwnedBitString, PrintableString, Sequence, SequenceOf,
-        SequenceOfWriter, SequenceWriter, SetOf, SetOfWriter, Tlv, UtcTime, Utf8String,
-        VisibleString,
+        parse_single, BMPString, BigUint, BitString, Choice1, Choice2, Choice3, Enumerated,
+        GeneralizedTime, IA5String, ObjectIdentifier, OwnedBitString, PrintableString, Sequence,
+        SequenceOf, SequenceOfWriter, SequenceWriter, SetOf, SetOfWriter, Tlv, UniversalString,
+        UtcTime, Utf8String, VisibleString,
     };
     #[cfg(feature = "const-generics")]
     use crate::{Explicit, Implicit};
@@ -237,6 +237,22 @@ mod tests {
         ]);
     }
 
+    #[test]
+    fn test_write_bmpstring() {
+        assert_writes::<BMPString>(&[(
+            BMPString::new(b"\x00a\x00b\x00c").unwrap(),
+            b"\x1e\x06\x00a\x00b\x00c",
+        )])
+    }
+
+    #[test]
+    fn test_write_universalstring() {
+        assert_writes::<UniversalString>(&[(
+            UniversalString::new(b"\x00\x00\x00a\x00\x00\x00b\x00\x00\x00c").unwrap(),
+            b"\x1c\x0c\x00\x00\x00a\x00\x00\x00b\x00\x00\x00c",
+        )])
+    }
+
     #[test]
     fn test_write_i64() {
         assert_writes::<i64>(&[
